@@ -10,6 +10,7 @@ from azure.identity import ClientSecretCredential
 from azure.common.credentials import ServicePrincipalCredentials
 from azure.mgmt.dns import DnsManagementClient
 from azure.mgmt.trafficmanager import TrafficManagerManagementClient
+from azure.core.pipeline.policies import RetryPolicy
 
 from azure.mgmt.dns.models import ARecord, AaaaRecord, CaaRecord, \
     CnameRecord, MxRecord, SrvRecord, NsRecord, PtrRecord, TxtRecord, Zone
@@ -20,7 +21,7 @@ from octodns.record import Record, Update, GeoCodes
 from octodns.provider import ProviderException
 from octodns.provider.base import BaseProvider
 
-__VERSION__ = '0.0.1'
+__VERSION__ = '0.0.2'
 
 
 class AzureException(ProviderException):
@@ -285,22 +286,23 @@ def _pool_traffic_manager_name(pool, record):
     return f'{prefix}-pool-{pool}'
 
 
-def _healthcheck_tolerated_number_of_failures(record):
+def _healthcheck_num_failures(record):
     return record._octodns.get('azuredns', {}) \
         .get('healthcheck', {}) \
-        .get('tolerated_number_of_failures')
+        .get('num_failures', 3)
 
 
-def _healthcheck_interval_in_seconds(record):
+def _healthcheck_interval(record):
     return record._octodns.get('azuredns', {}) \
         .get('healthcheck', {}) \
-        .get('interval_in_seconds')
+        .get('interval', 30)
 
 
-def _healthcheck_timeout_in_seconds(record):
+def _healthcheck_timeout(record):
+    default = 10 if _healthcheck_interval(record) > 10 else 9
     return record._octodns.get('azuredns', {}) \
         .get('healthcheck', {}) \
-        .get('timeout_in_seconds')
+        .get('timeout', default)
 
 
 def _get_monitor(record):
@@ -308,10 +310,9 @@ def _get_monitor(record):
         protocol=record.healthcheck_protocol,
         port=record.healthcheck_port,
         path=record.healthcheck_path,
-        interval_in_seconds=_healthcheck_interval_in_seconds(record),
-        timeout_in_seconds=_healthcheck_timeout_in_seconds(record),
-        tolerated_number_of_failures=
-        _healthcheck_tolerated_number_of_failures(record),
+        interval_in_seconds=_healthcheck_interval(record),
+        timeout_in_seconds=_healthcheck_timeout(record),
+        tolerated_number_of_failures=_healthcheck_num_failures(record),
     )
     host = record.healthcheck_host()
     if host:
@@ -503,10 +504,13 @@ class AzureProvider(BaseProvider):
                     'TXT'))
 
     def __init__(self, id, client_id, key, directory_id, sub_id,
-                 resource_group, *args, **kwargs):
+                 resource_group, client_total_retries=10,
+                 client_status_retries=3, *args, **kwargs):
         self.log = getLogger(f'AzureProvider[{id}]')
         self.log.debug('__init__: id=%s, client_id=%s, '
-                       'key=***, directory_id:%s', id, client_id, directory_id)
+                       'key=***, directory_id:%s, client_total_retries:%d, '
+                       'client_status_retries:%d', id, client_id, directory_id,
+                       client_total_retries, client_status_retries)
         super(AzureProvider, self).__init__(id, *args, **kwargs)
 
         # Store necessary initialization params
@@ -522,6 +526,11 @@ class AzureProvider(BaseProvider):
         self._azure_zones = set()
         self._traffic_managers = dict()
 
+        self._dns_client_retry_policy = RetryPolicy(
+            total_retries=client_total_retries,
+            status_retries=client_status_retries
+        )
+
     @property
     def _dns_client(self):
         if self.__dns_client is None:
@@ -539,6 +548,7 @@ class AzureProvider(BaseProvider):
                     logger=logger,
                 ),
                 subscription_id=self._dns_client_subscription_id,
+                retry_policy=self._dns_client_retry_policy
             )
         return self.__dns_client
 
@@ -690,8 +700,8 @@ class AzureProvider(BaseProvider):
 
             # dynamic record alias is broken, return dummy value and apply
             # will likely overwrite/fix it
-            self.log.warn('_data_for_A: Missing Traffic Manager alias for '
-                          'dynamic record %s', azrecord.fqdn)
+            self.log.warning('_data_for_A: Missing Traffic Manager alias for '
+                             'dynamic record %s', azrecord.fqdn)
             return {'values': []}
 
         return {'values': [ar.ipv4_address for ar in azrecord.a_records]}
@@ -703,8 +713,8 @@ class AzureProvider(BaseProvider):
 
             # dynamic record alias is broken, return dummy value and apply
             # will likely overwrite/fix it
-            self.log.warn('_data_for_AAAA: Missing Traffic Manager alias for '
-                          'dynamic record %s', azrecord.fqdn)
+            self.log.warning('_data_for_AAAA: Missing Traffic Manager alias '
+                             'for dynamic record %s', azrecord.fqdn)
             return {'values': []}
 
         return {'values': [ar.ipv6_address for ar in azrecord.aaaa_records]}
@@ -728,8 +738,8 @@ class AzureProvider(BaseProvider):
 
             # dynamic record alias is broken, return dummy value and apply
             # will likely overwrite/fix it
-            self.log.warn('_data_for_CNAME: Missing Traffic Manager alias for '
-                          'dynamic record %s', azrecord.fqdn)
+            self.log.warning('_data_for_CNAME: Missing Traffic Manager alias '
+                             'for dynamic record %s', azrecord.fqdn)
             return {'value': None}
 
         return {'value': _check_endswith_dot(azrecord.cname_record.cname)}
